//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.IO;
using System.Drawing;
using System.Windows.Forms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.MinApp
{
	/// <summary>
	/// Summary description for MainForm.
	/// </summary>
	public partial class MainForm : System.Windows.Forms.Form
	{
		/// <summary>
		/// Initializes a new instance of the MainForm class.
		/// </summary>
		public MainForm()
		{
			InitializeComponent();

			// Initialize the date file
			string exePath = Path.GetDirectoryName(Application.ExecutablePath);
			_dataFile = Path.Combine(exePath, "Schedule.dat");
		}


		private void btnMonthly_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.SingleMonth;
		}

		private void btnYearly_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.MonthRange;
		}

		private void btnWeekly_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.List;
		}

		private void btnCalendar_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.WeekRange;
		}

		private void btnSchedule_Click(object sender, EventArgs e)
		{
			_calendar.CurrentView = CalendarView.Timetable;
		}

		private void btnExit_Click(object sender, EventArgs e)
		{
			this.Close();
		}

		private void MainForm_Load(object sender, System.EventArgs e)
		{
			// Load the schedule from a file
			if (File.Exists(_dataFile))
			{
				_calendar.Schedule.LoadFrom(_dataFile,
					MindFusion.Scheduling.ContentType.Binary);
			}
		}

		private void MainForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			// Save the schedule to a file
			_calendar.Schedule.SaveTo(_dataFile,
				MindFusion.Scheduling.ContentType.Binary);
		}


		private string _dataFile;
	}
}
